@@ -13,9 +13,8 @@ timetau <- c(time[time<tau],tau)
 RR <- c( exp( x %*% beta) ) 
 cumhaz<- matrix(1,nrow=nrow(x)) %*% t(matrix(cumhaz,ncol=(ncol(out$cum)-1)))
 S0 <- exp(-cumhaz*RR)
-S0t <- Cpred(cbind(time,t(S0)),timetau)[,-1,drop=FALSE]
-S0t[,-1]
-Lam0t <- Cpred(cbind(time,t(cumhaz)),timetau)[,-1,drop=FALSE]
+S0t <- Cpred(cbind(time,t(S0)),timetau,strict=FALSE)[,-1,drop=FALSE]
+Lam0t <- Cpred(cbind(time,t(cumhaz)),timetau,strict=FALSE)[,-1,drop=FALSE]
 ll <- length(timetau)
 ee <- apply(diff(timetau)*S0t[-ll,,drop=FALSE],2,sum)
 deet <- apply(Lam0t[-ll,]*diff(timetau)*S0t[-ll,,drop=FALSE],2,sum)
@@ -34,7 +33,7 @@ if (iid==1) {
    }
    variid <- t(etiid) %*% etiid 
    se  <- diag(variid)^.5
-} else { var.mean <- se <- NULL }
+} else { variid <- se <- NULL }
 } ## }}}
 
 if (class(out)=="aalen")  ## {{{ 
@@ -45,7 +44,7 @@ cumhaz <- out$cum[,-1]
 timetau <- c(time[time<tau],tau)
 cumhaz<- as.matrix(x) %*% t(cumhaz)
 S0 <- exp(-cumhaz)
-S0t <- Cpred(cbind(time,t(S0)),timetau)[,-1,drop=FALSE]
+S0t <- Cpred(cbind(time,t(S0)),timetau,strict=FALSE)[,-1,drop=FALSE]
 Lam0t <- Cpred(cbind(time,t(cumhaz)),timetau)[,-1,drop=FALSE]
 ll <- length(timetau)
 ee <- apply(diff(timetau)*S0t[-ll,,drop=FALSE],2,sum)
@@ -65,10 +64,11 @@ if (iid==1) {
    }
    variid <- t(etiid) %*% etiid 
    se  <- diag(variid)^.5
-} else { var.mean <- se <- NULL }
+} else { variid <- se <- NULL }
 } ## }}}
 
-out <- list(mean=ee,var.mean=variid,se=se,S0tau=S0t[,-1],timetau=timetau[-1])
+out <- list(mean=ee,var.mean=variid,se=se,S0tau=S0t,timetau=timetau)
 return(out)
 } ## }}} 
 
+
